"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const native_icons_1 = __importDefault(require("native-icons"));
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const Progress = __importStar(require("react-native-progress"));
const DEFAULTS = {
    ICON_PAUSE: 'square',
    ICON_PLAY: 'pause',
    COLOR: '#fb2c53',
    PLACEHOLDER_COLOR: '#efefef',
};
const PROGRESS_WIDTH = 2;
const SIZES = {
    COMPACT: 12,
    NORMAL: 28,
};
const NativeCircularStatus = ({ progress, iconPause = DEFAULTS.ICON_PAUSE, iconPlay = DEFAULTS.ICON_PLAY, paused = false, renderContent, variant = 'normal', animated = true, color = DEFAULTS.COLOR, placeholderColor = DEFAULTS.PLACEHOLDER_COLOR, onPause, onPlay, onStatusChanged, thinking = false, disabled, contentProps = {}, iconProps = {}, placeholderProps = {}, progressProps = {}, ...containerProps }) => {
    const handlePress = react_1.useCallback(() => {
        if (thinking) {
            return;
        }
        if (paused) {
            onPlay?.();
        }
        else {
            onPause?.();
        }
        onStatusChanged?.(!paused);
    }, [onPause, onPlay, onStatusChanged, paused, thinking]);
    const size = react_1.useMemo(() => {
        switch (variant) {
            case 'compact':
                return SIZES.COMPACT;
            case 'normal':
            default:
                return SIZES.NORMAL;
        }
    }, [variant]);
    const { style: containerStyle = {}, ...containerRest } = containerProps;
    const { style: contentStyle = {}, ...contentRest } = contentProps;
    const { style: iconStyle = {}, ...iconRest } = iconProps;
    const { style: placeholderStyle = {}, ...placeholderRest } = placeholderProps;
    const innerComponent = react_1.useMemo(() => {
        if (renderContent) {
            return renderContent(progress, !!paused);
        }
        return (<native_icons_1.default type="ionicons" size={10} color={color} name={paused ? iconPlay : iconPause} style={react_native_1.StyleSheet.flatten([{ paddingLeft: 1 }, iconStyle])} {...iconRest}/>);
    }, [
        color,
        iconPause,
        iconPlay,
        iconStyle,
        paused,
        progress,
        renderContent,
        iconRest,
    ]);
    const isNormal = react_1.useMemo(() => variant === 'normal', [variant]);
    const isThinkingEnabled = react_1.useMemo(() => thinking && isNormal, [isNormal, thinking]);
    return (<react_native_1.TouchableOpacity onPress={handlePress} disabled={disabled} style={react_native_1.StyleSheet.flatten([
            styles.container,
            {
                width: size,
                height: size,
            },
            disabled ? styles.containerDisabled : {},
            containerStyle,
        ])} {...containerRest}>
      {!thinking && isNormal && (<react_native_1.View style={react_native_1.StyleSheet.flatten([
                styles.content,
                styles.absoluteElement,
                contentStyle,
            ])} {...contentRest}>
          {innerComponent}
        </react_native_1.View>)}

      {!isThinkingEnabled && (<react_native_1.View style={react_native_1.StyleSheet.flatten([
                styles.placeholder,
                styles.absoluteElement,
                {
                    borderRadius: size / 2,
                    borderColor: placeholderColor,
                },
                placeholderStyle,
            ])} {...placeholderRest}/>)}

      <Progress.Circle animated={animated} indeterminate={isThinkingEnabled} borderWidth={isThinkingEnabled ? PROGRESS_WIDTH : 0} borderColor={placeholderColor} color={color} progress={progress} size={size} thickness={PROGRESS_WIDTH} {...progressProps}/>
    </react_native_1.TouchableOpacity>);
};
const styles = react_native_1.StyleSheet.create({
    container: {
        position: 'relative',
    },
    containerDisabled: {
        opacity: 0.5,
    },
    content: {
        justifyContent: 'center',
        alignItems: 'center',
    },
    placeholder: {
        borderWidth: PROGRESS_WIDTH,
    },
    absoluteElement: {
        position: 'absolute',
        width: '100%',
        height: '100%',
    },
});
exports.default = NativeCircularStatus;
